Transaction

Struct Transaction 

pub struct Transaction { /* private fields */ }
High-level transaction wrapper with automatic cleanup and enhanced functionality

Implementations

Source

impl Transaction

pub async fn begin( pool: &ManagedPool, config: TransactionConfig, ) -> Result<Transaction, ModelError>

Create a new transaction with the given configuration

pub async fn begin_default( pool: &ManagedPool, ) -> Result<Transaction, ModelError>

Create a transaction with default configuration

pub async fn begin_read_only( pool: &ManagedPool, ) -> Result<Transaction, ModelError>

Create a read-only transaction

pub async fn begin_serializable( pool: &ManagedPool, ) -> Result<Transaction, ModelError>

Create a serializable transaction

pub fn is_active(&self) -> bool

Check if transaction is still active

pub fn as_mut(&mut self) -> Option<&mut Box<dyn DatabaseTransaction>>

Get a mutable reference to the underlying database transaction

Safety

This method provides direct access to the underlying transaction. Care should be taken not to commit or rollback the transaction directly as this will invalidate the Transaction wrapper.

pub fn as_ref(&self) -> Option<&Box<dyn DatabaseTransaction>>

Get an immutable reference to the underlying database transaction

pub async fn execute( &mut self, sql: &str, params: &[DatabaseValue], ) -> Result<u64, ModelError>

Execute a query within this transaction

pub async fn fetch_all( &mut self, sql: &str, params: &[DatabaseValue], ) -> Result<Vec<Box<dyn DatabaseRow>>, ModelError>

Fetch all rows from a query within this transaction

pub async fn fetch_optional( &mut self, sql: &str, params: &[DatabaseValue], ) -> Result<Option<Box<dyn DatabaseRow>>, ModelError>

Fetch optional single row from a query within this transaction

pub async fn execute_with<F, Fut, R>(&mut self, f: F) -> Result<R, ModelError>
where F: FnOnce(&mut Self) -> Fut, Fut: Future<Output = Result<R, ModelError>>,

Execute a closure within the transaction scope with a borrowed transaction

This is a safe way to execute database operations within a transaction. The closure receives access to execute queries against the transaction.

pub async fn commit(self) -> ModelResult<()>

Commit the transaction

pub async fn rollback(self) -> ModelResult<()>

Rollback the transaction

pub fn is_committed(&self) -> bool

Check if the transaction has been committed

pub fn config(&self) -> &TransactionConfig

Get the transaction configuration