pub struct Transaction { /* private fields */ }Expand description
High-level transaction wrapper with automatic cleanup and enhanced functionality
Implementations
Sourceimpl Transaction
impl Transaction
Sourcepub async fn begin(
pool: &ManagedPool,
config: TransactionConfig,
) -> Result<Transaction, ModelError>
pub async fn begin( pool: &ManagedPool, config: TransactionConfig, ) -> Result<Transaction, ModelError>
Create a new transaction with the given configuration
Sourcepub async fn begin_default(
pool: &ManagedPool,
) -> Result<Transaction, ModelError>
pub async fn begin_default( pool: &ManagedPool, ) -> Result<Transaction, ModelError>
Create a transaction with default configuration
Sourcepub async fn begin_read_only(
pool: &ManagedPool,
) -> Result<Transaction, ModelError>
pub async fn begin_read_only( pool: &ManagedPool, ) -> Result<Transaction, ModelError>
Create a read-only transaction
Sourcepub async fn begin_serializable(
pool: &ManagedPool,
) -> Result<Transaction, ModelError>
pub async fn begin_serializable( pool: &ManagedPool, ) -> Result<Transaction, ModelError>
Create a serializable transaction
Sourcepub fn as_mut(&mut self) -> Option<&mut Box<dyn DatabaseTransaction>>
pub fn as_mut(&mut self) -> Option<&mut Box<dyn DatabaseTransaction>>
Get a mutable reference to the underlying database transaction
Safety
This method provides direct access to the underlying transaction. Care should be taken not to commit or rollback the transaction directly as this will invalidate the Transaction wrapper.
Sourcepub fn as_ref(&self) -> Option<&Box<dyn DatabaseTransaction>>
pub fn as_ref(&self) -> Option<&Box<dyn DatabaseTransaction>>
Get an immutable reference to the underlying database transaction
Sourcepub async fn execute(
&mut self,
sql: &str,
params: &[DatabaseValue],
) -> Result<u64, ModelError>
pub async fn execute( &mut self, sql: &str, params: &[DatabaseValue], ) -> Result<u64, ModelError>
Execute a query within this transaction
Sourcepub async fn fetch_all(
&mut self,
sql: &str,
params: &[DatabaseValue],
) -> Result<Vec<Box<dyn DatabaseRow>>, ModelError>
pub async fn fetch_all( &mut self, sql: &str, params: &[DatabaseValue], ) -> Result<Vec<Box<dyn DatabaseRow>>, ModelError>
Fetch all rows from a query within this transaction
Sourcepub async fn fetch_optional(
&mut self,
sql: &str,
params: &[DatabaseValue],
) -> Result<Option<Box<dyn DatabaseRow>>, ModelError>
pub async fn fetch_optional( &mut self, sql: &str, params: &[DatabaseValue], ) -> Result<Option<Box<dyn DatabaseRow>>, ModelError>
Fetch optional single row from a query within this transaction
Sourcepub async fn execute_with<F, Fut, R>(&mut self, f: F) -> Result<R, ModelError>
pub async fn execute_with<F, Fut, R>(&mut self, f: F) -> Result<R, ModelError>
Execute a closure within the transaction scope with a borrowed transaction
This is a safe way to execute database operations within a transaction. The closure receives access to execute queries against the transaction.
Sourcepub async fn commit(self) -> ModelResult<()>
pub async fn commit(self) -> ModelResult<()>
Commit the transaction
Sourcepub async fn rollback(self) -> ModelResult<()>
pub async fn rollback(self) -> ModelResult<()>
Rollback the transaction
Sourcepub fn is_committed(&self) -> bool
pub fn is_committed(&self) -> bool
Check if the transaction has been committed
Sourcepub fn config(&self) -> &TransactionConfig
pub fn config(&self) -> &TransactionConfig
Get the transaction configuration